Enum AssayErrorModel
pub enum AssayErrorModel {
Additive {
lambda: Factor,
poly: ErrorPoly,
},
Proportional {
gamma: Factor,
poly: ErrorPoly,
},
None,
}Expand description
Model for calculating observation errors in pharmacometric analyses
An AssayErrorModel defines how the standard deviation of observations is calculated based on the type of error model used and its parameters.
Variants
Additive
Additive error model, where error is independent of concentration
Contains:
lambda- Lambda parameter for scaling errors (can be fixed or variable)poly- Error polynomial coefficients (c0, c1, c2, c3)
Fields
Proportional
Proportional error model, where error scales with concentration
Contains:
gamma- Gamma parameter for scaling errors (can be fixed or variable)poly- Error polynomial coefficients (c0, c1, c2, c3)
Fields
None
Implementations
impl AssayErrorModel
impl AssayErrorModel
pub fn additive(poly: ErrorPoly, lambda: f64) -> AssayErrorModel
pub fn additive(poly: ErrorPoly, lambda: f64) -> AssayErrorModel
pub fn additive_fixed(poly: ErrorPoly, lambda: f64) -> AssayErrorModel
pub fn additive_fixed(poly: ErrorPoly, lambda: f64) -> AssayErrorModel
pub fn additive_with_param(poly: ErrorPoly, lambda: Factor) -> AssayErrorModel
pub fn additive_with_param(poly: ErrorPoly, lambda: Factor) -> AssayErrorModel
pub fn proportional(poly: ErrorPoly, gamma: f64) -> AssayErrorModel
pub fn proportional(poly: ErrorPoly, gamma: f64) -> AssayErrorModel
pub fn proportional_fixed(poly: ErrorPoly, gamma: f64) -> AssayErrorModel
pub fn proportional_fixed(poly: ErrorPoly, gamma: f64) -> AssayErrorModel
pub fn proportional_with_param(
poly: ErrorPoly,
gamma: Factor,
) -> AssayErrorModel
pub fn proportional_with_param( poly: ErrorPoly, gamma: Factor, ) -> AssayErrorModel
pub fn errorpoly(&self) -> Result<ErrorPoly, ErrorModelError>
pub fn errorpoly(&self) -> Result<ErrorPoly, ErrorModelError>
pub fn set_errorpoly(&mut self, poly: ErrorPoly)
pub fn set_errorpoly(&mut self, poly: ErrorPoly)
pub fn factor(&self) -> Result<f64, ErrorModelError>
pub fn factor(&self) -> Result<f64, ErrorModelError>
Get the scaling parameter value
pub fn set_factor(&mut self, factor: f64)
pub fn set_factor(&mut self, factor: f64)
Set the scaling parameter value (preserves fixed/variable state)
pub fn factor_param(&self) -> Result<Factor, ErrorModelError>
pub fn factor_param(&self) -> Result<Factor, ErrorModelError>
Get the scaling parameter (including its fixed/variable state)
pub fn set_factor_param(&mut self, param: Factor)
pub fn set_factor_param(&mut self, param: Factor)
Set the scaling parameter (including its fixed/variable state)
pub fn is_factor_fixed(&self) -> Result<bool, ErrorModelError>
pub fn is_factor_fixed(&self) -> Result<bool, ErrorModelError>
Check if the scaling parameter is fixed
pub fn fix_factor(&mut self)
pub fn fix_factor(&mut self)
Make the scaling parameter fixed at its current value
pub fn unfix_factor(&mut self)
pub fn unfix_factor(&mut self)
Make the scaling parameter variable at its current value
pub fn is_proportional(&self) -> bool
pub fn is_proportional(&self) -> bool
Check if this is a proportional error model
Returns
true if this is a Proportional variant, false otherwise
pub fn is_additive(&self) -> bool
pub fn is_additive(&self) -> bool
Check if this is an additive error model
Returns
true if this is an Additive variant, false otherwise
pub fn sigma(&self, prediction: &Prediction) -> Result<f64, ErrorModelError>
pub fn sigma(&self, prediction: &Prediction) -> Result<f64, ErrorModelError>
Estimate the standard deviation for a prediction
Calculates the standard deviation based on the error model type, using either observation-specific error polynomial coefficients or the model’s default coefficients.
Arguments
prediction- The prediction for which to estimate the standard deviation
Returns
The estimated standard deviation of the prediction
pub fn variance(&self, prediction: &Prediction) -> Result<f64, ErrorModelError>
pub fn variance(&self, prediction: &Prediction) -> Result<f64, ErrorModelError>
Estimate the variance of the observation
This is a convenience function which calls AssayErrorModel::sigma, and squares the result.
pub fn sigma_from_value(&self, value: f64) -> Result<f64, ErrorModelError>
pub fn sigma_from_value(&self, value: f64) -> Result<f64, ErrorModelError>
Estimate the standard deviation for a raw observation value
Calculates the standard deviation based on the error model type, using the model’s default coefficients and a provided observation value.
Arguments
value- The observation value for which to estimate the standard deviation
Returns
The estimated standard deviation for the given value
pub fn variance_from_value(&self, value: f64) -> Result<f64, ErrorModelError>
pub fn variance_from_value(&self, value: f64) -> Result<f64, ErrorModelError>
Estimate the variance for a raw observation value
This is a convenience function which calls AssayErrorModel::sigma_from_value, and squares the result.