Occasion

Struct Occasion 

pub struct Occasion { /* private fields */ }
An occasion within a subject’s dataset

An Occasion represents a distinct period of data collection for a subject, such as a hospital visit or dosing regimen. It contains events (doses, observations) and time-varying covariates.

Implementations



impl Occasion

pub fn events(&self) -> &[Event]

Get a vector of references to all events in this occasion

Returns

A slice of all events in this occasion

pub fn index(&self) -> usize

Get the index of the occasion

Returns

The occasion index (0-based)

pub fn add_covariate(&mut self, name: String, covariate: Covariate)

Add a covariate to this occasion

Arguments
  • name - Name of the covariate
  • covariate - The covariate to add

pub fn covariates(&self) -> &Covariates

Get a reference to the covariates for this occasion

Returns

Reference to the occasion’s covariates, if any

pub fn covariates_mut(&mut self) -> &mut Covariates

Get a mutable refernce to the covariates for this occasion

Returns

Reference to the occasion’s covariates, if any

pub fn add_observation( &mut self, time: f64, value: f64, outeq: usize, errorpoly: Option<ErrorPoly>, censored: Censor, )

Add an Observation event to the Occasion

pub fn add_missing_observation(&mut self, time: f64, outeq: usize)

Add a missing Observation event to the Occasion

pub fn add_observation_with_error( &mut self, time: f64, value: f64, outeq: usize, errorpoly: ErrorPoly, censored: Censor, )

Add a missing Observation with a custom ErrorPoly to the Occasion

This is useful if you want a different weight for the observation

pub fn add_bolus(&mut self, time: f64, amount: f64, input: usize)

Add a Bolus event to the Occasion

pub fn add_infusion( &mut self, time: f64, amount: f64, input: usize, duration: f64, )

Add an Infusion event to the Occasion

pub fn events_mut(&mut self) -> &mut Vec<Event>

Get a mutable reference to the events

pub fn events_iter_mut(&mut self) -> IterMut<'_, Event>

Get a mutable iterator to the events

pub fn iter(&self) -> Iter<'_, Event>

Get an iterator over all events

Returns

An iterator yielding references to events

pub fn iter_mut(&mut self) -> IterMut<'_, Event>

Get a mutable iterator over all events

Returns

A mutable iterator yielding references to events

pub fn len(&self) -> usize

Get the number of events in this occasion

Returns

The number of events

pub fn is_empty(&self) -> bool

Check if the occasion has any events

Returns

true if there are no events, false otherwise



impl Occasion

pub fn nca_with_dose( &self, dose_amount: f64, route: Route, infusion_duration: Option<f64>, options: &NCAOptions, ) -> Result<NCAResult, NCAError>

Run NCA with an explicit dose, overriding what is embedded in the occasion.

Use this when you want to supply or override dose amount, route, or infusion duration without modifying the underlying data.