Struct Prediction
pub struct Prediction { /* private fields */ }Expand description
Prediction holds an observation and its prediction at a single time point.
This struct contains all information needed to calculate the likelihood contribution of a single observation.
Implementations
impl Prediction
impl Prediction
pub fn observation(&self) -> Option<f64>
pub fn observation(&self) -> Option<f64>
Get the observed value.
pub fn prediction(&self) -> f64
pub fn prediction(&self) -> f64
Get the predicted value.
pub fn prediction_error(&self) -> Option<f64>
pub fn prediction_error(&self) -> Option<f64>
Calculate the raw prediction error (prediction - observation).
pub fn percentage_error(&self) -> Option<f64>
pub fn percentage_error(&self) -> Option<f64>
Calculate the percentage error as (prediction - observation)/observation * 100.
pub fn absolute_error(&self) -> Option<f64>
pub fn absolute_error(&self) -> Option<f64>
Calculate the absolute error |prediction - observation|.
pub fn squared_error(&self) -> Option<f64>
pub fn squared_error(&self) -> Option<f64>
Calculate the squared error (prediction - observation)².
pub fn log_likelihood(
&self,
error_models: &AssayErrorModels,
) -> Result<f64, PharmsolError>
pub fn log_likelihood( &self, error_models: &AssayErrorModels, ) -> Result<f64, PharmsolError>
Calculate the log-likelihood of this prediction given an error model.
This method is numerically stable and handles:
- Regular observations: uses log-normal PDF
- BLOQ (below limit of quantification): uses log-CDF
- ALOQ (above limit of quantification): uses log-survival function
Error Model
Uses observation-based sigma from AssayErrorModels, which is appropriate
for non-parametric algorithms (NPAG, NPOD). For parametric algorithms
(SAEM, FOCE), use crate::ResidualErrorModels directly.
Parameters
error_models: The error models to use for sigma calculation
Returns
The log-likelihood value, zero in the case of a missing observation or an error if the likelihood is non-finite.
Example
let log_lik = prediction.log_likelihood(&error_models)?;pub fn likelihood(
&self,
error_models: &AssayErrorModels,
) -> Result<f64, PharmsolError>
👎Deprecated since 0.23.0: Use log_likelihood() instead for better numerical stability
pub fn likelihood( &self, error_models: &AssayErrorModels, ) -> Result<f64, PharmsolError>
Calculate the likelihood of this prediction.
Deprecated: Use log_likelihood instead for
better numerical stability. This method is provided for backward
compatibility and simply exponentiates the log-likelihood.
Parameters
error_models: The error models to use for sigma calculation
Returns
The likelihood value (exp of log-likelihood)
pub fn mut_occasion(&mut self) -> &mut usize
pub fn mut_occasion(&mut self) -> &mut usize
Get a mutable reference to the occasion index
pub fn to_observation(&self) -> Observation
pub fn to_observation(&self) -> Observation
Create an Observation from this prediction