Struct ResidualErrorModels
pub struct ResidualErrorModels { /* private fields */ }Expand description
Collection of residual error models for multiple output equations
This mirrors crate::ErrorModels but for parametric algorithms.
Implementations
impl ResidualErrorModels
impl ResidualErrorModels
pub fn new() -> ResidualErrorModels
pub fn new() -> ResidualErrorModels
Create an empty collection
pub fn add(self, outeq: usize, model: ResidualErrorModel) -> ResidualErrorModels
pub fn add(self, outeq: usize, model: ResidualErrorModel) -> ResidualErrorModels
Add an error model for a specific output equation
pub fn get(&self, outeq: usize) -> Option<&ResidualErrorModel>
pub fn get(&self, outeq: usize) -> Option<&ResidualErrorModel>
Get the error model for a specific output equation
pub fn get_mut(&mut self, outeq: usize) -> Option<&mut ResidualErrorModel>
pub fn get_mut(&mut self, outeq: usize) -> Option<&mut ResidualErrorModel>
Get a mutable reference to the error model for a specific output equation
pub fn sigma(&self, outeq: usize, prediction: f64) -> Option<f64>
pub fn sigma(&self, outeq: usize, prediction: f64) -> Option<f64>
Compute sigma for a specific output equation and prediction
pub fn iter(&self) -> impl Iterator<Item = (usize, &ResidualErrorModel)>
pub fn iter(&self) -> impl Iterator<Item = (usize, &ResidualErrorModel)>
Iterate over (outeq, model) pairs
pub fn total_log_likelihood<I>(&self, obs_pred_pairs: I) -> f64
pub fn total_log_likelihood<I>(&self, obs_pred_pairs: I) -> f64
pub fn update_sigma(&mut self, new_sigma: f64)
pub fn update_sigma(&mut self, new_sigma: f64)
Update all models with a new sigma estimate