Struct SdeLikelihoodCache
pub struct SdeLikelihoodCache(/* private fields */);Expand description
Cache for SDE likelihood values.
SDEs do not produce subject predictions that can be cached, but the likelihood values for a given subject and parameters can still be cached.
Note that the use of a cache could be counterproductive for SDEs, as this removes the stochastic nature of the likelihood evaluation. However, it can be useful for producing a deterministic likelihood for an otherwise stochastic process.
Clone produces a shallow clone that shares the same underlying cache data.
Implementations
impl SdeLikelihoodCache
impl SdeLikelihoodCache
pub fn new(size: u64) -> SdeLikelihoodCache
pub fn new(size: u64) -> SdeLikelihoodCache
Create a new SDE likelihood cache with the given maximum number of entries.
pub fn invalidate_all(&self)
pub fn invalidate_all(&self)
Remove all entries from the cache.
pub fn entry_count(&self) -> u64
pub fn entry_count(&self) -> u64
Return the number of entries currently in the cache.