AnalyticalEq

Type Alias AnalyticalEq 

pub type AnalyticalEq = fn(&NalgebraVec<f64>, &NalgebraVec<f64>, f64, &NalgebraVec<f64>, &Covariates) -> NalgebraVec<f64>;
This closure represents an Analytical solution of the model. See equation::analytical module for examples.

Parameters

  • x: The state vector at time t
  • p: The parameters of the model; Use the fetch_params! macro to extract the parameters
  • t: The time at which the output equation is evaluated
  • rateiv: A reference to a vector of infusion rates at time t
  • cov: A reference to the covariates at time t; Use the fetch_cov! macro to extract the covariates

TODO: Remove covariates. They are not used in the analytical solution