Struct AssayErrorModels
pub struct AssayErrorModels { /* private fields */ }Expand description
Collection of assay/measurement error models for all outputs.
This struct represents measurement/assay noise - the error associated with quantification of drug concentration in biological samples. Sigma is computed from the observation value.
Used by non-parametric algorithms (NPAG, NPOD, etc.).
For parametric algorithms (SAEM, FOCE), use crate::ResidualErrorModels instead,
which computes sigma from the prediction.
This is a wrapper around a vector of AssayErrorModels, its size is determined by the number of outputs in the model/dataset.
Implementations
impl AssayErrorModels
impl AssayErrorModels
pub fn new() -> AssayErrorModels
pub fn new() -> AssayErrorModels
pub fn error_model(
&self,
outeq: usize,
) -> Result<&AssayErrorModel, ErrorModelError>
pub fn error_model( &self, outeq: usize, ) -> Result<&AssayErrorModel, ErrorModelError>
Get the error model for a specific output equation
Arguments
outeq- The index of the output equation for which to retrieve the error model.
Returns
A reference to the AssayErrorModel for the specified output equation.
Errors
If the output equation index is invalid, an ErrorModelError::InvalidOutputEquation is returned.
pub fn add(
self,
outeq: usize,
model: AssayErrorModel,
) -> Result<AssayErrorModels, ErrorModelError>
pub fn add( self, outeq: usize, model: AssayErrorModel, ) -> Result<AssayErrorModels, ErrorModelError>
Add a new error model for a specific output equation
Arguments
outeq- The index of the output equation for which to add the error model.model- The AssayErrorModel to add for the specified output equation.
Returns
A new instance of AssayErrorModels with the added model.
Errors
If the output equation index is invalid or if a model already exists for that output equation, an ErrorModelError::ExistingOutputEquation is returned.
pub fn iter(&self) -> impl Iterator<Item = (usize, &AssayErrorModel)>
pub fn iter(&self) -> impl Iterator<Item = (usize, &AssayErrorModel)>
Returns an iterator over the error models in the collection.
Returns
An iterator that yields tuples containing the index and a reference to each AssayErrorModel.
pub fn into_iter(self) -> impl Iterator<Item = (usize, AssayErrorModel)>
pub fn into_iter(self) -> impl Iterator<Item = (usize, AssayErrorModel)>
Returns an iterator that yields mutable references to the error models in the collection.
Returns
An iterator that yields tuples containing the index and a mutable reference to each AssayErrorModel.
pub fn iter_mut(
&mut self,
) -> impl Iterator<Item = (usize, &mut AssayErrorModel)>
pub fn iter_mut( &mut self, ) -> impl Iterator<Item = (usize, &mut AssayErrorModel)>
Returns a mutable iterator that yields mutable references to the error models in the collection.
Returns
An iterator that yields tuples containing the index and a mutable reference to each AssayErrorModel.
pub fn hash(&self) -> u64
pub fn hash(&self) -> u64
Computes a hash for the error models collection. This hash is based on the output equations and their associated error models.
Returns
A u64 hash value representing the error models collection.
pub fn errorpoly(&self, outeq: usize) -> Result<ErrorPoly, ErrorModelError>
pub fn errorpoly(&self, outeq: usize) -> Result<ErrorPoly, ErrorModelError>
pub fn factor(&self, outeq: usize) -> Result<f64, ErrorModelError>
pub fn factor(&self, outeq: usize) -> Result<f64, ErrorModelError>
pub fn set_errorpoly(
&mut self,
outeq: usize,
poly: ErrorPoly,
) -> Result<(), ErrorModelError>
pub fn set_errorpoly( &mut self, outeq: usize, poly: ErrorPoly, ) -> Result<(), ErrorModelError>
pub fn set_factor(
&mut self,
outeq: usize,
factor: f64,
) -> Result<(), ErrorModelError>
pub fn set_factor( &mut self, outeq: usize, factor: f64, ) -> Result<(), ErrorModelError>
Sets the factor value for the specified output equation.
Arguments
outeq- The index of the output equation.factor- The new factor value to set.
pub fn factor_param(&self, outeq: usize) -> Result<Factor, ErrorModelError>
pub fn factor_param(&self, outeq: usize) -> Result<Factor, ErrorModelError>
pub fn set_factor_param(
&mut self,
outeq: usize,
param: Factor,
) -> Result<(), ErrorModelError>
pub fn set_factor_param( &mut self, outeq: usize, param: Factor, ) -> Result<(), ErrorModelError>
pub fn is_factor_fixed(&self, outeq: usize) -> Result<bool, ErrorModelError>
pub fn is_factor_fixed(&self, outeq: usize) -> Result<bool, ErrorModelError>
pub fn fix_factor(&mut self, outeq: usize) -> Result<(), ErrorModelError>
pub fn fix_factor(&mut self, outeq: usize) -> Result<(), ErrorModelError>
Makes the factor parameter fixed at its current value for the specified output equation.
Arguments
outeq- The index of the output equation.
pub fn unfix_factor(&mut self, outeq: usize) -> Result<(), ErrorModelError>
pub fn unfix_factor(&mut self, outeq: usize) -> Result<(), ErrorModelError>
Makes the factor parameter variable at its current value for the specified output equation.
Arguments
outeq- The index of the output equation.
pub fn is_proportional(&self, outeq: usize) -> bool
pub fn is_proportional(&self, outeq: usize) -> bool
pub fn is_additive(&self, outeq: usize) -> bool
pub fn is_additive(&self, outeq: usize) -> bool
pub fn sigma(&self, prediction: &Prediction) -> Result<f64, ErrorModelError>
pub fn sigma(&self, prediction: &Prediction) -> Result<f64, ErrorModelError>
Computes the standard deviation (sigma) for the specified output equation and prediction.
This always uses the observation value to compute sigma, which is appropriate
for non-parametric algorithms (NPAG, NPOD). For parametric algorithms (SAEM, FOCE),
use crate::ResidualErrorModels instead, which computes sigma from the prediction.
Arguments
prediction- ThePredictionto use for the calculation.
Returns
A Result containing the computed sigma value or an ErrorModelError if the calculation fails.
pub fn variance(&self, prediction: &Prediction) -> Result<f64, ErrorModelError>
pub fn variance(&self, prediction: &Prediction) -> Result<f64, ErrorModelError>
Computes the variance for the specified output equation and prediction.
Arguments
outeq- The index of the output equation.prediction- ThePredictionto use for the calculation.
Returns
A Result containing the computed variance or an ErrorModelError if the calculation fails.
pub fn sigma_from_value(
&self,
outeq: usize,
value: f64,
) -> Result<f64, ErrorModelError>
pub fn sigma_from_value( &self, outeq: usize, value: f64, ) -> Result<f64, ErrorModelError>
Computes the standard deviation (sigma) for the specified output equation and value.
Arguments
outeq- The index of the output equation.value- The value to use for the calculation.
Returns
A Result containing the computed sigma value or an ErrorModelError if the calculation fails.
pub fn variance_from_value(
&self,
outeq: usize,
value: f64,
) -> Result<f64, ErrorModelError>
pub fn variance_from_value( &self, outeq: usize, value: f64, ) -> Result<f64, ErrorModelError>
Computes the variance for the specified output equation and value.
Arguments
outeq- The index of the output equation.value- The value to use for the calculation.
Returns
A Result containing the computed variance or an ErrorModelError if the calculation fails.