Type Alias AnalyticalEq
pub type AnalyticalEq = fn(&NalgebraVec<f64>, &NalgebraVec<f64>, f64, &NalgebraVec<f64>, &Covariates) -> NalgebraVec<f64>;Expand description
This closure represents an Analytical solution of the model.
See equation::analytical module for examples.
Parameters
x: The state vector at time tp: The parameters of the model; Use thefetch_params!macro to extract the parameterst: The time at which the output equation is evaluatedrateiv: A reference to a vector of infusion rates at time tcov: A reference to the covariates at time t; Use thefetch_cov!macro to extract the covariates
TODO: Remove covariates. They are not used in the analytical solution